SLiCAPkicad.py — SLiCAP 3.5.1 documentation

# SLiCAPkicad.py

SLiCAP module for interfacing with KiCAD

KiCADsch2svg(fileName)

  Creates drawing-size images in .SVG and .PDF format from Kicad schematics. The image files will be placed in the img subdirectory in the project fodler. The names of the image files equal that of the schematic file, but the file extensions differ (.svg and .pdf).

  Parameters:

    fileName (str) – Name of the Kicad schematic file, relative to project folder or absolute